Index: /trunk/src/VBox/Frontends/VirtualBox/Makefile.kmk
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/Makefile.kmk	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/Makefile.kmk	(revision 41372)
@@ -361,9 +361,7 @@
 	src/wizards/UIWizardPage.h \
 	src/wizards/newvm/UIWizardNewVM.h \
-	src/wizards/newvm/UIWizardNewVMPageBasic1.h \
 	src/wizards/newvm/UIWizardNewVMPageBasic2.h \
 	src/wizards/newvm/UIWizardNewVMPageBasic3.h \
 	src/wizards/newvm/UIWizardNewVMPageBasic4.h \
-	src/wizards/newvm/UIWizardNewVMPageBasic5.h \
 	src/wizards/newvm/UIWizardNewVMPageExpert.h \
 	src/wizards/newvd/UIWizardNewVD.h \
@@ -371,5 +369,4 @@
 	src/wizards/newvd/UIWizardNewVDPageBasic2.h \
 	src/wizards/newvd/UIWizardNewVDPageBasic3.h \
-	src/wizards/newvd/UIWizardNewVDPageBasic4.h \
 	src/wizards/newvd/UIWizardNewVDPageExpert.h \
 	src/wizards/clonevm/UIWizardCloneVM.h \
@@ -383,5 +380,4 @@
 	src/wizards/clonevd/UIWizardCloneVDPageBasic3.h \
 	src/wizards/clonevd/UIWizardCloneVDPageBasic4.h \
-	src/wizards/clonevd/UIWizardCloneVDPageBasic5.h \
 	src/wizards/clonevd/UIWizardCloneVDPageExpert.h \
 	src/wizards/exportappliance/UIWizardExportApp.h \
@@ -396,8 +392,5 @@
 	src/wizards/importappliance/UIWizardImportAppPageExpert.h \
 	src/wizards/firstrun/UIWizardFirstRun.h \
-	src/wizards/firstrun/UIWizardFirstRunPageBasic1.h \
-	src/wizards/firstrun/UIWizardFirstRunPageBasic2.h \
-	src/wizards/firstrun/UIWizardFirstRunPageBasic3.h \
-	src/wizards/firstrun/UIWizardFirstRunPageExpert.h
+	src/wizards/firstrun/UIWizardFirstRunPageBasic2.h
 
 VirtualBox_QT_MOCHDRS.darwin += \
@@ -577,9 +570,7 @@
 	src/wizards/UIWizardPage.cpp \
 	src/wizards/newvm/UIWizardNewVM.cpp \
-	src/wizards/newvm/UIWizardNewVMPageBasic1.cpp \
 	src/wizards/newvm/UIWizardNewVMPageBasic2.cpp \
 	src/wizards/newvm/UIWizardNewVMPageBasic3.cpp \
 	src/wizards/newvm/UIWizardNewVMPageBasic4.cpp \
-	src/wizards/newvm/UIWizardNewVMPageBasic5.cpp \
 	src/wizards/newvm/UIWizardNewVMPageExpert.cpp \
 	src/wizards/newvd/UIWizardNewVD.cpp \
@@ -587,5 +578,4 @@
 	src/wizards/newvd/UIWizardNewVDPageBasic2.cpp \
 	src/wizards/newvd/UIWizardNewVDPageBasic3.cpp \
-	src/wizards/newvd/UIWizardNewVDPageBasic4.cpp \
 	src/wizards/newvd/UIWizardNewVDPageExpert.cpp \
 	src/wizards/clonevm/UIWizardCloneVM.cpp \
@@ -599,5 +589,4 @@
 	src/wizards/clonevd/UIWizardCloneVDPageBasic3.cpp \
 	src/wizards/clonevd/UIWizardCloneVDPageBasic4.cpp \
-	src/wizards/clonevd/UIWizardCloneVDPageBasic5.cpp \
 	src/wizards/clonevd/UIWizardCloneVDPageExpert.cpp \
 	src/wizards/exportappliance/UIWizardExportApp.cpp \
@@ -612,8 +601,5 @@
 	src/wizards/importappliance/UIWizardImportAppPageExpert.cpp \
 	src/wizards/firstrun/UIWizardFirstRun.cpp \
-	src/wizards/firstrun/UIWizardFirstRunPageBasic1.cpp \
-	src/wizards/firstrun/UIWizardFirstRunPageBasic2.cpp \
-	src/wizards/firstrun/UIWizardFirstRunPageBasic3.cpp \
-	src/wizards/firstrun/UIWizardFirstRunPageExpert.cpp
+	src/wizards/firstrun/UIWizardFirstRunPageBasic2.cpp
 
 VirtualBox_SOURCES.win += \
Index: /trunk/src/VBox/Frontends/VirtualBox/src/VBoxMediaManagerDlg.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/VBoxMediaManagerDlg.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/VBoxMediaManagerDlg.cpp	(revision 41372)
@@ -625,5 +625,5 @@
     mRefreshAction->setShortcut (QKeySequence (QKeySequence::Refresh));
 
-    mNewAction->setStatusTip (tr ("Create a new virtual hard disk"));
+    mNewAction->setStatusTip (tr ("Create a new virtual hard drive"));
     mAddAction->setStatusTip (tr ("Add an existing medium"));
     mCopyAction->setStatusTip (tr ("Copy an existing medium"));
@@ -1007,16 +1007,16 @@
     switch (type)
     {
+        case VBoxDefs::MediumType_HardDisk:
+        {
+            filterList = vboxGlobal().HDDBackends();
+            title = VBoxGlobal::tr("Please choose a virtual hard drive file");
+            allType = VBoxGlobal::tr("All virtual hard drive files (%1)");
+            break;
+        }
         case VBoxDefs::MediumType_DVD:
         {
             filterList = vboxGlobal().DVDBackends();
-            title = tr ("Select a CD/DVD-ROM disk image file");
-            allType = tr ("CD/DVD-ROM disk");
-            break;
-        }
-        case VBoxDefs::MediumType_HardDisk:
-        {
-            filterList = vboxGlobal().HDDBackends();
-            title = tr ("Select a hard disk image file");
-            allType = tr ("hard disk");
+            title = VBoxGlobal::tr("Please choose a virtual optical disk file");
+            allType = VBoxGlobal::tr("All virtual optical disk files (%1)");
             break;
         }
@@ -1024,6 +1024,6 @@
         {
             filterList = vboxGlobal().FloppyBackends();
-            title = tr ("Select a floppy disk image file");
-            allType = tr ("floppy disk");
+            title = VBoxGlobal::tr("Please choose a virtual floppy disk file");
+            allType = VBoxGlobal::tr("All virtual floppy disk files (%1)");
             break;
         }
@@ -1042,5 +1042,5 @@
     }
     if (!allPrefix.isEmpty())
-        backends.insert (0, tr ("All %1 images (%2)").arg (allType). arg (allPrefix.join (" ").trimmed()));
+        backends.insert(0, allType.arg(allPrefix.join(" ").trimmed()));
     backends << tr ("All files (*)");
     filter = backends.join (";;").trimmed();
Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/VBoxGlobal.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/VBoxGlobal.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/VBoxGlobal.cpp	(revision 41372)
@@ -2690,6 +2690,6 @@
         {
             filters = vboxGlobal().HDDBackends();
-            strTitle = tr ("Choose a virtual hard disk file");
-            allType = tr ("hard disk");
+            strTitle = tr("Please choose a virtual hard drive file");
+            allType = tr("All virtual hard drive files (%1)");
             strLastFolder = virtualBox().GetExtraData(VBoxDefs::GUI_RecentFolderHD);
             if (strLastFolder.isEmpty())
@@ -2702,6 +2702,6 @@
         {
             filters = vboxGlobal().DVDBackends();
-            strTitle = tr ("Choose a virtual CD/DVD disk file");
-            allType = tr ("CD/DVD-ROM disk");
+            strTitle = tr("Please choose a virtual optical disk file");
+            allType = tr("All virtual optical disk files (%1)");
             strLastFolder = virtualBox().GetExtraData(VBoxDefs::GUI_RecentFolderCD);
             if (strLastFolder.isEmpty())
@@ -2714,6 +2714,6 @@
         {
             filters = vboxGlobal().FloppyBackends();
-            strTitle = tr ("Choose a virtual floppy disk file");
-            allType = tr ("floppy disk");
+            strTitle = tr("Please choose a virtual floppy disk file");
+            allType = tr("All virtual floppy disk files (%1)");
             strLastFolder = virtualBox().GetExtraData(VBoxDefs::GUI_RecentFolderFD);
             if (strLastFolder.isEmpty())
@@ -2740,5 +2740,5 @@
     }
     if (!prefixes.isEmpty())
-        backends.insert(0, tr("All %1 images (%2)").arg(allType).arg(prefixes.join(" ").trimmed()));
+        backends.insert(0, allType.arg(prefixes.join(" ").trimmed()));
     backends << tr("All files (*)");
     strFilter = backends.join(";;").trimmed();
Index: /trunk/src/VBox/Frontends/VirtualBox/src/widgets/VBoxOSTypeSelectorWidget.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/widgets/VBoxOSTypeSelectorWidget.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/widgets/VBoxOSTypeSelectorWidget.cpp	(revision 41372)
@@ -152,5 +152,5 @@
 void VBoxOSTypeSelectorWidget::retranslateUi()
 {
-    mTxFamilyName->setText (tr ("Operating &System:"));
+    mTxFamilyName->setText (tr ("&Type:"));
     mCbFamily->setWhatsThis (tr ("Displays the operating system family that "
                                  "you plan to install into this virtual machine."));
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/UIWizard.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/UIWizard.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/UIWizard.cpp	(revision 41372)
@@ -39,6 +39,14 @@
 void UIWizard::sltCurrentIdChanged(int iId)
 {
-    /* Enable 1st button (Hide/Show Description) for 1st page only: */
-    setOption(QWizard::HaveCustomButton1, iId == 0);
+    /* Hide/show description button disabled by default: */
+    bool fIsHideShowDescriptionButtonAvailable = false;
+    /* Enable hide/show description button for 1st page: */
+    if (iId == 0)
+        fIsHideShowDescriptionButtonAvailable = true;
+    /* But first-run wizard has no such button anyway: */
+    if (m_type == UIWizardType_FirstRun)
+        fIsHideShowDescriptionButtonAvailable = false;
+    /* Set a flag for hide/show description button finally: */
+    setOption(QWizard::HaveCustomButton1, fIsHideShowDescriptionButtonAvailable);
 }
 
@@ -401,5 +409,9 @@
         case UIWizardType_NewVD:
         case UIWizardType_CloneVD:
+        case UIWizardType_ExportAppliance:
             dRatio += 0.3;
+            break;
+        case UIWizardType_FirstRun:
+            dRatio += 0.4;
             break;
         default:
@@ -532,12 +544,13 @@
 UIWizardMode UIWizard::loadModeForType(UIWizardType type)
 {
-    /* Default mode is Basic: */
-    UIWizardMode mode = UIWizardMode_Basic;
+    /* Some wizard use only basic mode: */
+    if (type == UIWizardType_FirstRun)
+        return UIWizardMode_Basic;
     /* Get mode from extra-data: */
     QStringList wizards = vboxGlobal().virtualBox().GetExtraDataStringList(VBoxDefs::GUI_HideDescriptionForWizards);
     if (wizards.contains(nameForType(type)))
-        mode = UIWizardMode_Expert;
+        return UIWizardMode_Expert;
     /* Return mode: */
-    return mode;
-}
-
+    return UIWizardMode_Basic;
+}
+
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/UIWizardPage.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/UIWizardPage.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/UIWizardPage.cpp	(revision 41372)
@@ -70,19 +70,4 @@
 }
 
-QString UIWizardPage::standardHelpText() const
-{
-    return tr("Use the <b>%1</b> button to go to the next page of the wizard and the "
-              "<b>%2</b> button to return to the previous page. "
-              "You can also press <b>%3</b> if you want to cancel the execution "
-              "of this wizard.</p>")
-        .arg(VBoxGlobal::replaceHtmlEntities(VBoxGlobal::removeAccelMark(wizard()->buttonText(QWizard::NextButton).remove(" >"))))
-        .arg(VBoxGlobal::replaceHtmlEntities(VBoxGlobal::removeAccelMark(wizard()->buttonText(QWizard::BackButton).remove("< "))))
-#ifdef Q_WS_MAC
-        .arg(QKeySequence("ESC").toString()); /* There is no button shown on Mac OS X, so just say the key sequence. */
-#else /* Q_WS_MAC */
-        .arg(VBoxGlobal::replaceHtmlEntities(VBoxGlobal::removeAccelMark(wizard()->buttonText(QWizard::CancelButton))));
-#endif /* Q_WS_MAC */
-}
-
 void UIWizardPage::startProcessing()
 {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/UIWizardPage.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/UIWizardPage.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/UIWizardPage.h	(revision 41372)
@@ -67,5 +67,4 @@
     /* Helpers: */
     UIWizard* wizard() const;
-    QString standardHelpText() const;
     void startProcessing();
     void endProcessing();
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVD.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVD.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVD.cpp	(revision 41372)
@@ -27,5 +27,4 @@
 #include "UIWizardCloneVDPageBasic3.h"
 #include "UIWizardCloneVDPageBasic4.h"
-#include "UIWizardCloneVDPageBasic5.h"
 #include "UIWizardCloneVDPageExpert.h"
 #include "VBoxGlobal.h"
@@ -102,5 +101,5 @@
 
     /* Translate wizard: */
-    setWindowTitle(tr("Copy Virtual Disk"));
+    setWindowTitle(tr("Copy Virtual Hard Drive"));
     setButtonText(QWizard::FinishButton, tr("Copy"));
 }
@@ -117,5 +116,4 @@
             setPage(Page3, new UIWizardCloneVDPageBasic3);
             setPage(Page4, new UIWizardCloneVDPageBasic4);
-            setPage(Page5, new UIWizardCloneVDPageBasic5);
             break;
         }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVD.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVD.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVD.h	(revision 41372)
@@ -24,5 +24,5 @@
 #include "COMDefs.h"
 
-/* Clone Virtual Disk wizard: */
+/* Clone Virtual Hard Drive wizard: */
 class UIWizardCloneVD : public UIWizard
 {
@@ -37,6 +37,5 @@
         Page2,
         Page3,
-        Page4,
-        Page5
+        Page4
     };
 
@@ -59,5 +58,5 @@
 
     /* Who will be able to copy virtual-disk: */
-    friend class UIWizardCloneVDPageBasic5;
+    friend class UIWizardCloneVDPageBasic4;
     friend class UIWizardCloneVDPageExpert;
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic1.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic1.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic1.cpp	(revision 41372)
@@ -104,4 +104,7 @@
     /* Call to base-class: */
     onHandleOpenSourceDiskClick();
+
+    /* Broadcast complete-change: */
+    emit completeChanged();
 }
 
@@ -109,15 +112,12 @@
 {
     /* Translate page: */
-    setTitle(UIWizardCloneVD::tr("Welcome to the Copy Virtual Disk wizard!"));
+    setTitle(UIWizardCloneVD::tr("Hard drive to copy"));
 
     /* Translate widgets: */
-    m_pLabel->setText(UIWizardCloneVD::tr("<p>This wizard will help you to copy a virtual disk.</p>"));
-    m_pLabel->setText(m_pLabel->text() + QString("<p>%1</p>").arg(standardHelpText()));
-    m_pLabel->setText(m_pLabel->text() + UIWizardCloneVD::tr("Please select the virtual disk which you would like "
-                                                             "to copy if it is not already selected. You can either "
-                                                             "choose one from the list or use the folder icon "
-                                                             "beside the list to select a virtual disk file."));
-    m_pSourceDiskCnt->setTitle(UIWizardCloneVD::tr("Virtual disk to copy"));
-    m_pSourceDiskOpenButton->setToolTip(UIWizardCloneVD::tr("Choose a virtual hard disk file..."));
+    m_pLabel->setText(UIWizardCloneVD::tr("<p>Please select the virtual hard drive file that you would like to copy "
+                                          "if it is not already selected. You can either choose one from the list "
+                                          "or use the folder icon beside the list to select one.</p>"));
+    m_pSourceDiskCnt->setTitle(UIWizardCloneVD::tr("Hard drive to &copy"));
+    m_pSourceDiskOpenButton->setToolTip(UIWizardCloneVD::tr("Choose a virtual hard drive file to copy..."));
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic1.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic1.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic1.h	(revision 41372)
@@ -30,5 +30,5 @@
 class QIRichTextLabel;
 
-/* 1st page of the Clone Virtual Disk wizard (base part): */
+/* 1st page of the Clone Virtual Hard Drive wizard (base part): */
 class UIWizardCloneVDPage1 : public UIWizardPageBase
 {
@@ -51,5 +51,5 @@
 };
 
-/* 1st page of the Clone Virtual Disk wizard (basic extension): */
+/* 1st page of the Clone Virtual Hard Drive wizard (basic extension): */
 class UIWizardCloneVDPageBasic1 : public UIWizardPage, public UIWizardCloneVDPage1
 {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic2.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic2.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic2.cpp	(revision 41372)
@@ -137,11 +137,10 @@
 {
     /* Translate page: */
-    setTitle(UIWizardCloneVD::tr("Virtual disk file type"));
+    setTitle(UIWizardCloneVD::tr("File type"));
 
     /* Translate widgets: */
-    m_pLabel->setText(UIWizardCloneVD::tr("Please choose the type of file that you would like "
-                                          "to use for the new virtual disk. If you do not need "
-                                          "to use it with other virtualization software you can "
-                                          "leave this setting unchanged."));
+    m_pLabel->setText(UIWizardCloneVD::tr("Please choose the type of file that you would like to use "
+                                          "for the new virtual hard drive. If you do not need to use it "
+                                          "with other virtualization software you can leave this setting unchanged."));
     m_pFormatCnt->setTitle(UIWizardCloneVD::tr("File &type"));
     QList<QAbstractButton*> buttons = m_pFormatButtonGroup->buttons();
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic2.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic2.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic2.h	(revision 41372)
@@ -31,5 +31,5 @@
 class QIRichTextLabel;
 
-/* 2nd page of the Clone Virtual Disk wizard (base part): */
+/* 2nd page of the Clone Virtual Hard Drive wizard (base part): */
 class UIWizardCloneVDPage2 : public UIWizardPageBase
 {
@@ -55,5 +55,5 @@
 };
 
-/* 2nd page of the Clone Virtual Disk wizard (basic extension): */
+/* 2nd page of the Clone Virtual Hard Drive wizard (basic extension): */
 class UIWizardCloneVDPageBasic2 : public UIWizardPage, public UIWizardCloneVDPage2
 {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic3.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic3.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic3.cpp	(revision 41372)
@@ -122,19 +122,18 @@
 {
     /* Translate page: */
-    setTitle(UIWizardCloneVD::tr("Virtual disk storage details"));
+    setTitle(UIWizardCloneVD::tr("Storage details"));
 
     /* Translate widgets: */
-    m_pDescriptionLabel->setText(UIWizardCloneVD::tr("Please choose whether the new virtual disk file should be "
+    m_pDescriptionLabel->setText(UIWizardCloneVD::tr("Please choose whether the new virtual hard drive file should be "
                                                      "allocated as it is used or if it should be created fully allocated."));
-    m_pDynamicLabel->setText(UIWizardCloneVD::tr("<p>A <b>dynamically allocated</b> virtual disk file will only use space on "
-                                                 "your physical hard disk as it fills up (up to a <b>fixed maximum size</b>), "
+    m_pDynamicLabel->setText(UIWizardCloneVD::tr("<p>A <b>dynamically allocated</b> hard drive file will only use space "
+                                                 "on your physical hard drive as it fills up (up to a <b>fixed maximum size</b>), "
                                                  "although it will not shrink again automatically when space on it is freed.</p>"));
-    m_pFixedLabel->setText(UIWizardCloneVD::tr("<p>A <b>fixed size</b> virtual disk file may take longer to create on some "
+    m_pFixedLabel->setText(UIWizardCloneVD::tr("<p>A <b>fixed size</b> hard drive file may take longer to create on some "
                                                "systems but is often faster to use.</p>"));
-    m_pSplitLabel->setText(UIWizardCloneVD::tr("<p>You can also choose to <b>split</b> the virtual disk into several files "
+    m_pSplitLabel->setText(UIWizardCloneVD::tr("<p>You can also choose to <b>split</b> the hard drive file into several files "
                                                "of up to two gigabytes each. This is mainly useful if you wish to store the "
                                                "virtual machine on removable USB devices or old systems, some of which cannot "
                                                "handle very large files."));
-
     m_pVariantCnt->setTitle(UIWizardCloneVD::tr("Storage details"));
     m_pDynamicalButton->setText(UIWizardCloneVD::tr("&Dynamically allocated"));
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic3.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic3.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic3.h	(revision 41372)
@@ -30,5 +30,5 @@
 class QIRichTextLabel;
 
-/* 3rd page of the Clone Virtual Disk wizard (base part): */
+/* 3rd page of the Clone Virtual Hard Drive wizard (base part): */
 class UIWizardCloneVDPage3 : public UIWizardPageBase
 {
@@ -50,5 +50,5 @@
 };
 
-/* 3rd page of the Clone Virtual Disk wizard (basic extension): */
+/* 3rd page of the Clone Virtual Hard Drive wizard (basic extension): */
 class UIWizardCloneVDPageBasic3 : public UIWizardPage, public UIWizardCloneVDPage3
 {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic4.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic4.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic4.h	(revision 41372)
@@ -34,5 +34,5 @@
 class QIRichTextLabel;
 
-/* 4th page of the Clone Virtual Disk wizard (base part): */
+/* 4th page of the Clone Virtual Hard Drive wizard (base part): */
 class UIWizardCloneVDPage4 : public UIWizardPageBase
 {
@@ -66,5 +66,5 @@
 };
 
-/* 4th page of the Clone Virtual Disk wizard (basic extension): */
+/* 4th page of the Clone Virtual Hard Drive wizard (basic extension): */
 class UIWizardCloneVDPageBasic4 : public UIWizardPage, public UIWizardCloneVDPage4
 {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageExpert.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageExpert.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageExpert.cpp	(revision 41372)
@@ -191,5 +191,5 @@
     m_strDefaultPath = sourceFileInfo.absolutePath();
     /* Compose name for virtual-disk copy: */
-    QString strMediumName = UIWizardCloneVD::tr("%1_copy", "copied virtual disk name").arg(sourceFileInfo.baseName());
+    QString strMediumName = UIWizardCloneVD::tr("%1_copy", "copied virtual hard drive name").arg(sourceFileInfo.baseName());
     /* Set text to location editor: */
     m_pDestinationDiskEditor->setText(strMediumName);
@@ -203,4 +203,7 @@
     /* Call to base-class: */
     onHandleOpenSourceDiskClick();
+
+    /* Broadcast complete-change: */
+    emit completeChanged();
 }
 
@@ -235,8 +238,8 @@
 {
     /* Translate widgets: */
-    m_pSourceDiskCnt->setTitle(UIWizardCloneVD::tr("&Source virtual disk"));
-    m_pSourceDiskOpenButton->setToolTip(UIWizardCloneVD::tr("Choose a virtual hard disk file..."));
-    m_pDestinationCnt->setTitle(UIWizardCloneVD::tr("&Destination virtual disk"));
-    m_pDestinationDiskOpenButton->setToolTip(UIWizardCloneVD::tr("Choose a virtual hard disk file..."));
+    m_pSourceDiskCnt->setTitle(UIWizardCloneVD::tr("Hard drive to &copy"));
+    m_pSourceDiskOpenButton->setToolTip(UIWizardCloneVD::tr("Choose a virtual hard drive file to copy..."));
+    m_pDestinationCnt->setTitle(UIWizardCloneVD::tr("Copy &location"));
+    m_pDestinationDiskOpenButton->setToolTip(UIWizardCloneVD::tr("Choose a location for new virtual hard drive file..."));
     m_pFormatCnt->setTitle(UIWizardCloneVD::tr("File &type"));
     QList<QAbstractButton*> buttons = m_pFormatButtonGroup->buttons();
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageExpert.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageExpert.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageExpert.h	(revision 41372)
@@ -25,13 +25,11 @@
 #include "UIWizardCloneVDPageBasic3.h"
 #include "UIWizardCloneVDPageBasic4.h"
-#include "UIWizardCloneVDPageBasic5.h"
 
-/* Expert page of the Clone Virtual Disk wizard: */
+/* Expert page of the Clone Virtual Hard Drive wizard: */
 class UIWizardCloneVDPageExpert : public UIWizardPage,
                                   public UIWizardCloneVDPage1,
                                   public UIWizardCloneVDPage2,
                                   public UIWizardCloneVDPage3,
-                                  public UIWizardCloneVDPage4,
-                                  public UIWizardCloneVDPage5
+                                  public UIWizardCloneVDPage4
 {
     Q_OBJECT;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevm/UIWizardCloneVMPageBasic1.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevm/UIWizardCloneVMPageBasic1.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevm/UIWizardCloneVMPageBasic1.cpp	(revision 41372)
@@ -57,5 +57,4 @@
     {
         m_pLabel1 = new QIRichTextLabel(this);
-        m_pLabel2 = new QIRichTextLabel(this);
         m_pNameCnt = new QGroupBox(this);
         {
@@ -71,5 +70,4 @@
         m_pReinitMACsCheckBox = new QCheckBox(this);
         pMainLayout->addWidget(m_pLabel1);
-        pMainLayout->addWidget(m_pLabel2);
         pMainLayout->addWidget(m_pNameCnt);
         pMainLayout->addWidget(m_pReinitMACsCheckBox);
@@ -88,10 +86,10 @@
 {
     /* Translate page: */
-    setTitle(UIWizardCloneVM::tr("Welcome to the Clone Virtual Machine wizard!"));
+    setTitle(UIWizardCloneVM::tr("Name"));
 
     /* Translate widgets: */
-    m_pLabel1->setText(UIWizardCloneVM::tr("<p>This wizard will help you to create a clone of your virtual machine.</p>"));
-    m_pLabel1->setText(m_pLabel1->text() + QString("<p>%1</p>").arg(standardHelpText()));
-    m_pLabel2->setText(UIWizardCloneVM::tr("<p>Please choose a name for the new virtual machine:</p>"));
+    m_pLabel1->setText(UIWizardCloneVM::tr("<p>Please choose a name for the new virtual machine. "
+                                           "The new machine will be a clone of the machine <b>%1</b>.</p>")
+                                           .arg(m_strOriginalName));
     m_pNameCnt->setTitle(UIWizardCloneVM::tr("&Name"));
     m_pReinitMACsCheckBox->setToolTip(UIWizardCloneVM::tr("When checked a new unique MAC address will be assigned to all configured network cards."));
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevm/UIWizardCloneVMPageBasic1.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevm/UIWizardCloneVMPageBasic1.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevm/UIWizardCloneVMPageBasic1.h	(revision 41372)
@@ -78,5 +78,4 @@
     /* Widgets: */
     QIRichTextLabel *m_pLabel1;
-    QIRichTextLabel *m_pLabel2;
 };
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevm/UIWizardCloneVMPageBasic2.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevm/UIWizardCloneVMPageBasic2.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevm/UIWizardCloneVMPageBasic2.cpp	(revision 41372)
@@ -91,17 +91,21 @@
 {
     /* Translate page: */
-    setTitle(UIWizardCloneVM::tr("Cloning Configuration"));
+    setTitle(UIWizardCloneVM::tr("Type"));
 
     /* Translate widgets: */
-    QString strLabel = UIWizardCloneVM::tr("<p>Please select the type of the clone.</p><p>If you choose <b>Full Clone</b> an exact copy "
-                                           "(including all virtual disk images) of the original VM will be created. If you select <b>Linked Clone</b>, "
-                                           "a new VM will be created, but the virtual disk images will point to the virtual disk images of original VM.</p>");
+    QString strLabel = UIWizardCloneVM::tr("<p>Please select the type of the clone.</p>"
+                                           "<p>If you choose <b>Full clone</b>, "
+                                           "an exact copy (including all virtual hard drive images) "
+                                           "of the original VM will be created.</p>"
+                                           "<p>If you select <b>Linked clone</b>, "
+                                           "a new VM will be created, but the virtual hard drive images "
+                                           "will point to the virtual hard drive images of original VM.</p>");
     if (m_fAdditionalInfo)
-        strLabel += UIWizardCloneVM::tr("<p>Note that a new snapshot within the source VM is created in case you select <b>Linked Clone</b>.</p>");
+        strLabel += UIWizardCloneVM::tr("<p>Note that a new snapshot within the source VM is created in case you select <b>Linked clone</b>.</p>");
     m_pLabel->setText(strLabel);
 
     m_pCloneTypeCnt->setTitle(UIWizardCloneVM::tr("&Type"));
-    m_pFullCloneRadio->setText(UIWizardCloneVM::tr("Full Clone"));
-    m_pLinkedCloneRadio->setText(UIWizardCloneVM::tr("Linked Clone"));
+    m_pFullCloneRadio->setText(UIWizardCloneVM::tr("Full clone"));
+    m_pLinkedCloneRadio->setText(UIWizardCloneVM::tr("Linked clone"));
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevm/UIWizardCloneVMPageBasic3.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevm/UIWizardCloneVMPageBasic3.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevm/UIWizardCloneVMPageBasic3.cpp	(revision 41372)
@@ -92,14 +92,14 @@
 {
     /* Translate page: */
-    setTitle(UIWizardCloneVM::tr("Cloning Configuration"));
+    setTitle(UIWizardCloneVM::tr("Mode"));
 
     /* Translate widgets: */
-    const QString strGeneral = UIWizardCloneVM::tr("Please choose which parts of the virtual machine should be cloned.");
-    const QString strOpt1    = UIWizardCloneVM::tr("If you select <b>Current machine state</b>, only the current state "
-                                                   "of the virtual machine is cloned.");
-    const QString strOpt2    = UIWizardCloneVM::tr("If you select <b>Current machine and all child states</b> the current state "
-                                                   "of the virtual machine and any states of child snapshots are cloned.");
-    const QString strOpt3    = UIWizardCloneVM::tr("If you select <b>All states</b>, the current machine state "
-                                                   "and all snapshots are cloned.");
+    const QString strGeneral = UIWizardCloneVM::tr("<p>Please choose which parts of the virtual machine should be cloned.</p>");
+    const QString strOpt1    = UIWizardCloneVM::tr("<p>If you select <b>Current machine state</b>, "
+                                                   "only the current state of the virtual machine is cloned.</p>");
+    const QString strOpt2    = UIWizardCloneVM::tr("<p>If you select <b>Current machine and all child states</b>, "
+                                                   "the current state of the virtual machine and any states of child snapshots are cloned.</p>");
+    const QString strOpt3    = UIWizardCloneVM::tr("<p>If you select <b>All states</b>, "
+                                                   "the current machine state and all snapshots are cloned.</p>");
     if (m_fShowChildsOption)
         m_pLabel->setText(QString("<p>%1</p><p>%2 %3 %4</p>")
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportApp.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportApp.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportApp.cpp	(revision 41372)
@@ -232,5 +232,5 @@
 
     /* Translate wizard: */
-    setWindowTitle(tr("Appliance Export Wizard"));
+    setWindowTitle(tr("Export Virtual Appliance"));
     setButtonText(QWizard::CustomButton2, tr("Restore Defaults"));
     setButtonText(QWizard::FinishButton, tr("Export"));
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic1.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic1.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic1.cpp	(revision 41372)
@@ -108,16 +108,10 @@
     {
         m_pLabel = new QIRichTextLabel(this);
-        m_pVMSelectorLabel = new QILabelSeparator(this);
-        {
-            m_pVMSelectorLabel->hide();
-        }
         m_pVMSelector = new QListWidget(this);
         {
             m_pVMSelector->setAlternatingRowColors(true);
             m_pVMSelector->setSelectionMode(QAbstractItemView::ExtendedSelection);
-            m_pVMSelectorLabel->setBuddy(m_pVMSelector);
         }
         pMainLayout->addWidget(m_pLabel);
-        pMainLayout->addWidget(m_pVMSelectorLabel);
         pMainLayout->addWidget(m_pVMSelector);
         populateVMSelectorItems(selectedVMNames);
@@ -135,15 +129,10 @@
 {
     /* Translate page: */
-    setTitle(UIWizardExportApp::tr("Welcome to the Appliance Export wizard!"));
+    setTitle(UIWizardExportApp::tr("Virtual machines to export"));
 
     /* Translate widgets: */
-    m_pLabel->setText(UIWizardExportApp::tr("<p>This wizard will guide you through the process of "
-                                            "exporting an appliance.</p><p>%1</p><p>Please select "
-                                            "the virtual machines that should be added to the "
-                                            "appliance. You can select more than one. Please note "
-                                            "that these machines have to be turned off before they "
-                                            "can be exported.</p>")
-                                            .arg(standardHelpText()));
-    m_pVMSelectorLabel->setText(UIWizardExportApp::tr("VM &List"));
+    m_pLabel->setText(UIWizardExportApp::tr("<p>Please select the virtual machines that should be added to the appliance. "
+                                            "You can select more than one. Please note that these machines have to be "
+                                            "turned off before they can be exported.</p>"));
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic1.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic1.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic1.h	(revision 41372)
@@ -24,5 +24,4 @@
 
 /* Forward declarations: */
-class QILabelSeparator;
 class QListWidget;
 class QIRichTextLabel;
@@ -46,5 +45,4 @@
 
     /* Widgets: */
-    QILabelSeparator *m_pVMSelectorLabel;
     QListWidget *m_pVMSelector;
 };
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic2.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic2.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic2.cpp	(revision 41372)
@@ -113,13 +113,12 @@
 {
     /* Translate page: */
-    setTitle(UIWizardExportApp::tr("Appliance Export Settings"));
+    setTitle(UIWizardExportApp::tr("Appliance settings"));
 
     /* Translate widgets: */
-    m_pLabel->setText(UIWizardExportApp::tr("Please specify the target for the OVF export. "
-                                            "You can choose between a local file system export, "
-                                            "uploading the OVF to the Sun Cloud service "
-                                            "or an S3 storage server."));
-    m_pTypeCnt->setTitle(UIWizardExportApp::tr("&Destination"));
-    m_pTypeLocalFilesystem->setText(UIWizardExportApp::tr("&Local Filesystem "));
+    m_pLabel->setText(UIWizardExportApp::tr("Please choose where to create the virtual appliance. "
+                                            "You can create it on your own computer, "
+                                            "on the Sun Cloud service or on an S3 storage server."));
+    m_pTypeCnt->setTitle(UIWizardExportApp::tr("Create on"));
+    m_pTypeLocalFilesystem->setText(UIWizardExportApp::tr("&This computer"));
     m_pTypeSunCloud->setText(UIWizardExportApp::tr("Sun &Cloud"));
     m_pTypeSimpleStorageSystem->setText(UIWizardExportApp::tr("&Simple Storage System (S3)"));
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic3.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic3.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic3.cpp	(revision 41372)
@@ -270,5 +270,5 @@
 {
     /* Translate page: */
-    setTitle(UIWizardExportApp::tr("Appliance Export Settings"));
+    setTitle(UIWizardExportApp::tr("Appliance settings"));
 
     /* Translate objects: */
@@ -280,5 +280,5 @@
     m_pBucketLabel->setText(UIWizardExportApp::tr("&Bucket:"));
     m_pFileSelectorLabel->setText(UIWizardExportApp::tr("&File:"));
-    m_pFileSelector->setFileDialogTitle(UIWizardExportApp::tr("Select a file to export into"));
+    m_pFileSelector->setFileDialogTitle(UIWizardExportApp::tr("Please choose a virtual appliance file"));
     m_pFileSelector->setFileFilters(UIWizardExportApp::tr("Open Virtualization Format Archive (%1)").arg("*.ova") + ";;" +
                                     UIWizardExportApp::tr("Open Virtualization Format (%1)").arg("*.ovf"));
@@ -287,4 +287,7 @@
     m_pManifestCheckbox->setToolTip(UIWizardExportApp::tr("Create a Manifest file for automatic data integrity checks on import."));
     m_pManifestCheckbox->setText(UIWizardExportApp::tr("Write &Manifest file"));
+
+    /* Refresh current settings: */
+    refreshCurrentSettings();
 }
 
@@ -293,7 +296,4 @@
     /* Translate page: */
     retranslateUi();
-
-    /* Refresh current settings: */
-    refreshCurrentSettings();
 }
 
@@ -345,9 +345,10 @@
         case Filesystem:
         {
-            m_pLabel->setText(tr("Please choose a filename to export the OVF/OVA to. "
-                                 "If you use an <i>ova</i> file name extension, then all the files "
-                                 "will be combined into one Open Virtualization Format Archive. "
-                                 "If you use an <i>ovf</i> extension, several files "
-                                 "will be written separately. Other extensions are not allowed."));
+            m_pLabel->setText(tr("<p>Please choose a filename to export the OVF/OVA to.</p>"
+                                 "<p>If you use an <i>ova</i> extension, "
+                                 "then all the files will be combined into one Open Virtualization Format Archive.</p>"
+                                 "<p>If you use an <i>ovf</i> extension, "
+                                 "several files will be written separately.</p>"
+                                 "<p>Other extensions are not allowed.</p>"));
             m_pFileSelector->setFocus();
             break;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic4.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic4.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic4.cpp	(revision 41372)
@@ -82,15 +82,9 @@
     {
         m_pLabel = new QIRichTextLabel(this);
-        m_pVMApplianceLabel = new QILabelSeparator(this);
-        {
-            m_pVMApplianceLabel->hide();
-        }
         m_pApplianceWidget = new UIApplianceExportEditorWidget(this);
         {
             m_pApplianceWidget->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::MinimumExpanding);
-            m_pVMApplianceLabel->setBuddy(m_pApplianceWidget);
         }
         pMainLayout->addWidget(m_pLabel);
-        pMainLayout->addWidget(m_pVMApplianceLabel);
         pMainLayout->addWidget(m_pApplianceWidget);
     }
@@ -105,12 +99,10 @@
 {
     /* Translate page: */
-    setTitle(UIWizardExportApp::tr("Appliance Export Settings"));
+    setTitle(UIWizardExportApp::tr("Appliance settings"));
 
     /* Translate widgets: */
-    m_pLabel->setText(UIWizardExportApp::tr("Here you can change additional configuration "
-                                            "values of the selected virtual machines. "
-                                            "You can modify most of the properties shown "
-                                            "by double-clicking on the items."));
-    m_pVMApplianceLabel->setText(UIWizardExportApp::tr("&Settings"));
+    m_pLabel->setText(UIWizardExportApp::tr("This is the descriptive information which will be added "
+                                            "to the virtual appliance.  You can change it by double "
+                                            "clicking on individual lines."));
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic4.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic4.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic4.h	(revision 41372)
@@ -28,5 +28,4 @@
 
 /* Forward declarations: */
-class QILabelSeparator;
 class UIWizardExportApp;
 class QIRichTextLabel;
@@ -47,5 +46,4 @@
 
     /* Widgets: */
-    QILabelSeparator *m_pVMApplianceLabel;
     UIApplianceExportEditorWidget *m_pApplianceWidget;
 };
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageExpert.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageExpert.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageExpert.cpp	(revision 41372)
@@ -188,6 +188,6 @@
     m_strDefaultApplianceName = UIWizardExportApp::tr("Appliance");
     /* Translate widgets: */
-    m_pVMSelectorLabel->setText(UIWizardExportApp::tr("VM &List"));
-    m_pVMApplianceLabel->setText(UIWizardExportApp::tr("&Settings"));
+    m_pVMSelectorLabel->setText(UIWizardExportApp::tr("Virtual &machines to export"));
+    m_pVMApplianceLabel->setText(UIWizardExportApp::tr("Appliance &settings"));
     m_pTypeCnt->setTitle(UIWizardExportApp::tr("&Destination"));
     m_pTypeLocalFilesystem->setText(UIWizardExportApp::tr("&Local Filesystem "));
@@ -199,5 +199,5 @@
     m_pBucketLabel->setText(UIWizardExportApp::tr("&Bucket:"));
     m_pFileSelectorLabel->setText(UIWizardExportApp::tr("&File:"));
-    m_pFileSelector->setFileDialogTitle(UIWizardExportApp::tr("Select a file to export into"));
+    m_pFileSelector->setFileDialogTitle(UIWizardExportApp::tr("Please choose a virtual appliance file"));
     m_pFileSelector->setFileFilters(UIWizardExportApp::tr("Open Virtualization Format Archive (%1)").arg("*.ova") + ";;" +
                                     UIWizardExportApp::tr("Open Virtualization Format (%1)").arg("*.ovf"));
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageExpert.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageExpert.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageExpert.h	(revision 41372)
@@ -25,4 +25,7 @@
 #include "UIWizardExportAppPageBasic3.h"
 #include "UIWizardExportAppPageBasic4.h"
+
+/* Forward declarations: */
+class QILabelSeparator;
 
 /* Expert page of the Export Appliance wizard: */
@@ -82,4 +85,8 @@
     bool isComplete() const;
     bool validatePage();
+
+    /* Widgets: */
+    QILabelSeparator *m_pVMSelectorLabel;
+    QILabelSeparator *m_pVMApplianceLabel;
 };
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/firstrun/UIWizardFirstRun.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/firstrun/UIWizardFirstRun.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/firstrun/UIWizardFirstRun.cpp	(revision 41372)
@@ -20,8 +20,5 @@
 /* Local includes: */
 #include "UIWizardFirstRun.h"
-#include "UIWizardFirstRunPageBasic1.h"
 #include "UIWizardFirstRunPageBasic2.h"
-#include "UIWizardFirstRunPageBasic3.h"
-#include "UIWizardFirstRunPageExpert.h"
 #include "VBoxGlobal.h"
 #include "UIMessageCenter.h"
@@ -92,5 +89,5 @@
 
     /* Translate wizard: */
-    setWindowTitle(tr("First Run Wizard"));
+    setWindowTitle(tr("Select start-up disk"));
     setButtonText(QWizard::FinishButton, tr("Start"));
 }
@@ -103,12 +100,10 @@
         case UIWizardMode_Basic:
         {
-            setPage(Page1, new UIWizardFirstRunPageBasic1(m_fHardDiskWasSet));
-            setPage(Page2, new UIWizardFirstRunPageBasic2(m_machine.GetId(), m_fHardDiskWasSet));
-            setPage(Page3, new UIWizardFirstRunPageBasic3(m_fHardDiskWasSet));
+            setPage(Page1, new UIWizardFirstRunPageBasic2(m_machine.GetId(), m_fHardDiskWasSet));
             break;
         }
         case UIWizardMode_Expert:
         {
-            setPage(PageExpert, new UIWizardFirstRunPageExpert(m_machine.GetId(), m_fHardDiskWasSet));
+            AssertMsgFailed(("First-run wizard has no expert-mode!"));
             break;
         }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/firstrun/UIWizardFirstRun.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/firstrun/UIWizardFirstRun.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/firstrun/UIWizardFirstRun.h	(revision 41372)
@@ -54,6 +54,5 @@
 
     /* Who will be able to export appliance: */
-    friend class UIWizardFirstRunPageBasic3;
-    friend class UIWizardFirstRunPageExpert;
+    friend class UIWizardFirstRunPageBasic2;
 
 private:
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/firstrun/UIWizardFirstRunPageBasic2.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/firstrun/UIWizardFirstRunPageBasic2.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/firstrun/UIWizardFirstRunPageBasic2.cpp	(revision 41372)
@@ -64,4 +64,5 @@
     QVBoxLayout *pMainLayout = new QVBoxLayout(this);
     {
+        pMainLayout->setContentsMargins(8, 0, 8, 0);
         m_pLabel = new QIRichTextLabel(this);
         m_pSourceCnt = new QGroupBox(this);
@@ -107,18 +108,24 @@
 void UIWizardFirstRunPageBasic2::retranslateUi()
 {
-    /* Translate page: */
-    setTitle(UIWizardFirstRun::tr("Select Installation Media"));
-
     /* Translate widgets: */
     if (m_fBootHardDiskWasSet)
-        m_pLabel->setText(UIWizardFirstRun::tr("<p>Select the media which contains the setup program "
-                                               "of the operating system you want to install. This media must be bootable, "
-                                               "otherwise the setup program will not be able to start.</p>"));
+        m_pLabel->setText(UIWizardFirstRun::tr("<p>Please select a virtual optical disk file "
+                                               "or a physical optical drive containing a disk "
+                                               "to start your new virtual machine from.</p>"
+                                               "<p>The disk should be suitable for starting a computer from "
+                                               "and should contain the operating system you wish to install "
+                                               "on the virtual machine if you want to do that now. "
+                                               "The disk will be ejected from the virtual drive "
+                                               "automatically next time you switch the virtual machine off, "
+                                               "but you can also do this yourself if needed using the Devices menu.</p>"));
     else
-        m_pLabel->setText(UIWizardFirstRun::tr("<p>Select the media that contains the operating system "
-                                               "you want to work with. This media must be bootable, "
-                                               "otherwise the operating system will not be able to start.</p>"));
-    m_pSourceCnt->setTitle(UIWizardFirstRun::tr("Media Source"));
-    m_pSelectMediaButton->setToolTip(VBoxGlobal::tr("Choose a virtual CD/DVD disk file"));
+        m_pLabel->setText(UIWizardFirstRun::tr("<p>Please select a virtual optical disk file "
+                                               "or a physical optical drive containing a disk "
+                                               "to start your new virtual machine from.</p>"
+                                               "<p>The disk should be suitable for starting a computer from. "
+                                               "As this virtual machine has no hard drive "
+                                               "you will not be able to install an operating system on it at the moment.</p>"));
+    m_pSourceCnt->setTitle(UIWizardFirstRun::tr("Start-up disk"));
+    m_pSelectMediaButton->setToolTip(UIWizardFirstRun::tr("Choose a virtual optical disk file..."));
 }
 
@@ -135,4 +142,23 @@
 }
 
+bool UIWizardFirstRunPageBasic2::validatePage()
+{
+    /* Initial result: */
+    bool fResult = true;
+
+    /* Lock finish button: */
+    startProcessing();
+
+    /* Try to insert chosen medium: */
+    if (fResult)
+        fResult = qobject_cast<UIWizardFirstRun*>(wizard())->insertMedium();
+
+    /* Unlock finish button: */
+    endProcessing();
+
+    /* Return result: */
+    return fResult;
+}
+
 QString UIWizardFirstRunPageBasic2::source() const
 {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/firstrun/UIWizardFirstRunPageBasic2.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/firstrun/UIWizardFirstRunPageBasic2.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/firstrun/UIWizardFirstRunPageBasic2.h	(revision 41372)
@@ -87,4 +87,7 @@
     bool isComplete() const;
 
+    /* Validation stuff: */
+    bool validatePage();
+
     /* Stuff for 'source' field: */
     QString source() const;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportApp.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportApp.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportApp.cpp	(revision 41372)
@@ -210,5 +210,5 @@
 
     /* Translate wizard: */
-    setWindowTitle(tr("Appliance Import Wizard"));
+    setWindowTitle(tr("Import Virtual Applicance"));
     setButtonText(QWizard::CustomButton2, tr("Restore Defaults"));
     setButtonText(QWizard::FinishButton, tr("Import"));
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.cpp	(revision 41372)
@@ -57,12 +57,10 @@
 {
     /* Translate page: */
-    setTitle(UIWizardImportApp::tr("Welcome to the Appliance Import wizard!"));
+    setTitle(UIWizardImportApp::tr("Appliance to import"));
 
     /* Translate widgets: */
-    m_pLabel->setText(UIWizardImportApp::tr("<p>This wizard will guide you through importing an appliance.</p>"
-                                            "<p>%1</p><p>VirtualBox currently supports importing appliances "
-                                            "saved in the Open Virtualization Format (OVF). To continue, "
-                                            "select the file to import below:</p>")
-                                           .arg(standardHelpText()));
+    m_pLabel->setText(UIWizardImportApp::tr("<p>VirtualBox currently supports importing appliances "
+                                            "saved in the Open Virtualization Format (OVF). "
+                                            "To continue, select the file to import below.</p>"));
     m_pFileSelector->setChooseButtonText(UIWizardImportApp::tr("Open appliance..."));
     m_pFileSelector->setFileDialogTitle(UIWizardImportApp::tr("Select an appliance to import"));
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic2.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic2.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic2.cpp	(revision 41372)
@@ -54,5 +54,5 @@
 {
     /* Translate page: */
-    setTitle(UIWizardImportApp::tr("Appliance Import Settings"));
+    setTitle(UIWizardImportApp::tr("Appliance settings"));
 
     /* Translate widgets: */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageExpert.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageExpert.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageExpert.cpp	(revision 41372)
@@ -26,4 +26,5 @@
 #include "UIWizardImportApp.h"
 #include "VBoxGlobal.h"
+#include "QILabelSeparator.h"
 #include "VBoxFilePathSelectorWidget.h"
 #include "UIApplianceImportEditorWidget.h"
@@ -35,4 +36,5 @@
     {
         pMainLayout->setContentsMargins(8, 6, 8, 6);
+        m_pVMApplianceLabel = new QILabelSeparator(this);
         m_pFileSelector = new VBoxEmptyFileSelector(this);
         {
@@ -45,4 +47,5 @@
             m_pApplianceWidget->setFile(strFileName);
         }
+        pMainLayout->addWidget(m_pVMApplianceLabel);
         pMainLayout->addWidget(m_pFileSelector);
         pMainLayout->addWidget(m_pApplianceWidget);
@@ -73,4 +76,5 @@
 {
     /* Translate widgets: */
+    m_pVMApplianceLabel->setText(UIWizardImportApp::tr("Appliance to import"));
     m_pFileSelector->setChooseButtonText(UIWizardImportApp::tr("Open appliance..."));
     m_pFileSelector->setFileDialogTitle(UIWizardImportApp::tr("Select an appliance to import"));
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageExpert.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageExpert.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageExpert.h	(revision 41372)
@@ -23,4 +23,7 @@
 #include "UIWizardImportAppPageBasic1.h"
 #include "UIWizardImportAppPageBasic2.h"
+
+/* Forward declarations: */
+class QILabelSeparator;
 
 /* Expert page of the Import Appliance wizard: */
@@ -53,4 +56,7 @@
     bool isComplete() const;
     bool validatePage();
+
+    /* Widgets: */
+    QILabelSeparator *m_pVMApplianceLabel;
 };
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVD.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVD.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVD.cpp	(revision 41372)
@@ -26,5 +26,4 @@
 #include "UIWizardNewVDPageBasic2.h"
 #include "UIWizardNewVDPageBasic3.h"
-#include "UIWizardNewVDPageBasic4.h"
 #include "UIWizardNewVDPageExpert.h"
 #include "VBoxGlobal.h"
@@ -102,5 +101,5 @@
 
     /* Translate wizard: */
-    setWindowTitle(tr("Create New Virtual Disk"));
+    setWindowTitle(tr("Create Virtual Hard Drive"));
     setButtonText(QWizard::FinishButton, tr("Create"));
 }
@@ -116,5 +115,4 @@
             setPage(Page2, new UIWizardNewVDPageBasic2);
             setPage(Page3, new UIWizardNewVDPageBasic3(m_strDefaultName, m_strDefaultPath, m_uDefaultSize));
-            setPage(Page4, new UIWizardNewVDPageBasic4);
             break;
         }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVD.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVD.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVD.h	(revision 41372)
@@ -24,5 +24,5 @@
 #include "COMDefs.h"
 
-/* New Virtual Disk wizard: */
+/* New Virtual Hard Drive wizard: */
 class UIWizardNewVD : public UIWizard
 {
@@ -36,6 +36,5 @@
         Page1,
         Page2,
-        Page3,
-        Page4
+        Page3
     };
 
@@ -60,5 +59,5 @@
 
     /* Who will be able to create virtual-disk: */
-    friend class UIWizardNewVDPageBasic4;
+    friend class UIWizardNewVDPageBasic3;
     friend class UIWizardNewVDPageExpert;
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic1.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic1.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic1.cpp	(revision 41372)
@@ -137,13 +137,10 @@
 {
     /* Translate page: */
-    setTitle(UIWizardNewVD::tr("Welcome to the New Virtual Disk wizard!"));
+    setTitle(UIWizardNewVD::tr("File type"));
 
     /* Translate widgets: */
-    m_pLabel->setText(UIWizardNewVD::tr("<p>This wizard will help you to create a new virtual disk for your virtual machine.</p>"));
-    m_pLabel->setText(m_pLabel->text() + QString("<p>%1</p>").arg(standardHelpText()));
-    m_pLabel->setText(m_pLabel->text() + UIWizardNewVD::tr("<p>Please choose the type of file that you would like "
-                                                           "to use for the new virtual disk. If you do not need "
-                                                           "to use it with other virtualization software you can "
-                                                           "leave this setting unchanged.</p>"));
+    m_pLabel->setText(UIWizardNewVD::tr("Please choose the type of file that you would like to use "
+                                        "for the new virtual hard drive. If you do not need to use it "
+                                        "with other virtualization software you can leave this setting unchanged."));
     m_pFormatCnt->setTitle(UIWizardNewVD::tr("File &type"));
     QList<QAbstractButton*> buttons = m_pFormatButtonGroup->buttons();
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic1.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic1.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic1.h	(revision 41372)
@@ -31,5 +31,5 @@
 class QIRichTextLabel;
 
-/* 1st page of the New Virtual Disk wizard (base part): */
+/* 1st page of the New Virtual Hard Drive wizard (base part): */
 class UIWizardNewVDPage1 : public UIWizardPageBase
 {
@@ -55,5 +55,5 @@
 };
 
-/* 1st page of the New Virtual Disk wizard (basic extension): */
+/* 1st page of the New Virtual Hard Drive wizard (basic extension): */
 class UIWizardNewVDPageBasic1 : public UIWizardPage, public UIWizardNewVDPage1
 {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic2.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic2.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic2.cpp	(revision 41372)
@@ -122,15 +122,15 @@
 {
     /* Translate page: */
-    setTitle(UIWizardNewVD::tr("Virtual disk storage details"));
+    setTitle(UIWizardNewVD::tr("Storage details"));
 
     /* Translate widgets: */
-    m_pDescriptionLabel->setText(UIWizardNewVD::tr("Please choose whether the new virtual disk file should be "
+    m_pDescriptionLabel->setText(UIWizardNewVD::tr("Please choose whether the new virtual hard drive file should be "
                                                    "allocated as it is used or if it should be created fully allocated."));
-    m_pDynamicLabel->setText(UIWizardNewVD::tr("<p>A <b>dynamically allocated</b> virtual disk file will only use space on "
-                                               "your physical hard disk as it fills up (up to a <b>fixed maximum size</b>), "
+    m_pDynamicLabel->setText(UIWizardNewVD::tr("<p>A <b>dynamically allocated</b> hard drive file will only use space "
+                                               "on your physical hard drive as it fills up (up to a <b>fixed maximum size</b>), "
                                                "although it will not shrink again automatically when space on it is freed.</p>"));
-    m_pFixedLabel->setText(UIWizardNewVD::tr("<p>A <b>fixed size</b> virtual disk file may take longer to create on some "
+    m_pFixedLabel->setText(UIWizardNewVD::tr("<p>A <b>fixed size</b> hard drive file may take longer to create on some "
                                              "systems but is often faster to use.</p>"));
-    m_pSplitLabel->setText(UIWizardNewVD::tr("<p>You can also choose to <b>split</b> the virtual disk into several files "
+    m_pSplitLabel->setText(UIWizardNewVD::tr("<p>You can also choose to <b>split</b> the hard drive file into several files "
                                              "of up to two gigabytes each. This is mainly useful if you wish to store the "
                                              "virtual machine on removable USB devices or old systems, some of which cannot "
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic2.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic2.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic2.h	(revision 41372)
@@ -30,5 +30,5 @@
 class QIRichTextLabel;
 
-/* 2nd page of the New Virtual Disk wizard (base part): */
+/* 2nd page of the New Virtual Hard Drive wizard (base part): */
 class UIWizardNewVDPage2 : public UIWizardPageBase
 {
@@ -50,5 +50,5 @@
 };
 
-/* 2nd page of the New Virtual Disk wizard (basic extension): */
+/* 2nd page of the New Virtual Hard Drive wizard (basic extension): */
 class UIWizardNewVDPageBasic2 : public UIWizardPage, public UIWizardNewVDPage2
 {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic3.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic3.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic3.h	(revision 41372)
@@ -33,5 +33,5 @@
 class QIRichTextLabel;
 
-/* 3rd page of the New Virtual Disk wizard (base part): */
+/* 3rd page of the New Virtual Hard Drive wizard (base part): */
 class UIWizardNewVDPage3 : public UIWizardPageBase
 {
@@ -82,5 +82,5 @@
 };
 
-/* 3rd page of the New Virtual Disk wizard (basic extension): */
+/* 3rd page of the New Virtual Hard Drive wizard (basic extension): */
 class UIWizardNewVDPageBasic3 : public UIWizardPage, public UIWizardNewVDPage3
 {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageExpert.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageExpert.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageExpert.cpp	(revision 41372)
@@ -256,5 +256,5 @@
     /* Translate widgets: */
     m_pLocationCnt->setTitle(UIWizardNewVD::tr("&Location"));
-    m_pLocationOpenButton->setToolTip(UIWizardNewVD::tr("Choose a virtual hard disk file..."));
+    m_pLocationOpenButton->setToolTip(UIWizardNewVD::tr("Choose a virtual hard drive file..."));
     m_pSizeCnt->setTitle(UIWizardNewVD::tr("&Size"));
     m_pFormatCnt->setTitle(UIWizardNewVD::tr("File &type"));
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageExpert.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageExpert.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageExpert.h	(revision 41372)
@@ -24,12 +24,10 @@
 #include "UIWizardNewVDPageBasic2.h"
 #include "UIWizardNewVDPageBasic3.h"
-#include "UIWizardNewVDPageBasic4.h"
 
-/* Expert page of the New Virtual Disk wizard: */
+/* Expert page of the New Virtual Hard Drive wizard: */
 class UIWizardNewVDPageExpert : public UIWizardPage,
                                 public UIWizardNewVDPage1,
                                 public UIWizardNewVDPage2,
-                                public UIWizardNewVDPage3,
-                                public UIWizardNewVDPage4
+                                public UIWizardNewVDPage3
 {
     Q_OBJECT;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVM.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVM.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVM.cpp	(revision 41372)
@@ -20,9 +20,7 @@
 /* Local includes: */
 #include "UIWizardNewVM.h"
-#include "UIWizardNewVMPageBasic1.h"
 #include "UIWizardNewVMPageBasic2.h"
 #include "UIWizardNewVMPageBasic3.h"
 #include "UIWizardNewVMPageBasic4.h"
-#include "UIWizardNewVMPageBasic5.h"
 #include "UIWizardNewVMPageExpert.h"
 #include "VBoxDefs.h"
@@ -69,6 +67,6 @@
         }
 
-        /* The FirstRun wizard is to be shown only when we don't attach any virtual disk or attach a new (empty) one.
-         * Selecting an existing virtual disk will cancel the FirstRun wizard. */
+        /* The FirstRun wizard is to be shown only when we don't attach any virtual hard drive or attach a new (empty) one.
+         * Selecting an existing virtual hard drive will cancel the FirstRun wizard. */
         if (field("virtualDiskId").toString().isNull() || !field("virtualDisk").value<CMedium>().isNull())
             m_machine.SetExtraData(VBoxDefs::GUI_FirstRun, "yes");
@@ -200,5 +198,5 @@
 
             QString strId = field("virtualDiskId").toString();
-            /* Boot virtual disk: */
+            /* Boot virtual hard drive: */
             if (!strId.isNull())
             {
@@ -249,5 +247,5 @@
     }
 
-    /* Ensure we don't try to delete a newly created virtual disk on success: */
+    /* Ensure we don't try to delete a newly created virtual hard drive on success: */
     if (!field("virtualDisk").value<CMedium>().isNull())
         field("virtualDisk").value<CMedium>().detach();
@@ -262,5 +260,5 @@
 
     /* Translate wizard: */
-    setWindowTitle(tr("Create New Virtual Machine"));
+    setWindowTitle(tr("Create Virtual Machine"));
     setButtonText(QWizard::FinishButton, tr("Create"));
 }
@@ -273,9 +271,7 @@
         case UIWizardMode_Basic:
         {
-            setPage(Page1, new UIWizardNewVMPageBasic1);
-            setPage(Page2, new UIWizardNewVMPageBasic2);
-            setPage(Page3, new UIWizardNewVMPageBasic3);
-            setPage(Page4, new UIWizardNewVMPageBasic4);
-            setPage(Page5, new UIWizardNewVMPageBasic5);
+            setPage(Page1, new UIWizardNewVMPageBasic2);
+            setPage(Page2, new UIWizardNewVMPageBasic3);
+            setPage(Page3, new UIWizardNewVMPageBasic4);
             break;
         }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVM.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVM.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVM.h	(revision 41372)
@@ -37,6 +37,5 @@
         Page2,
         Page3,
-        Page4,
-        Page5
+        Page4
     };
 
@@ -56,5 +55,5 @@
 
     /* Who will be able to create virtual-machine: */
-    friend class UIWizardNewVMPageBasic5;
+    friend class UIWizardNewVMPageBasic4;
     friend class UIWizardNewVMPageExpert;
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic2.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic2.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic2.cpp	(revision 41372)
@@ -281,13 +281,13 @@
 {
     /* Translate page: */
-    setTitle(UIWizardNewVM::tr("VM Name and OS Type"));
+    setTitle(UIWizardNewVM::tr("Name and operating system"));
 
     /* Translate widgets: */
-    m_pLabel->setText(UIWizardNewVM::tr("<p>Enter a name for the new virtual machine and select the type of the guest operating system "
-                                        "you plan to install onto the virtual machine.</p><p>The name of the virtual machine usually "
-                                        "indicates its software and hardware configuration. It will be used by all VirtualBox components "
-                                        "to identify your virtual machine.</p>"));
+    m_pLabel->setText(UIWizardNewVM::tr("Please choose a descriptive name for the new virtual machine "
+                                        "and select the type of operating system you intend to install on it. "
+                                        "The name you choose will be used throughout VirtualBox "
+                                        "to identify this machine."));
     m_pNameCnt->setTitle(UIWizardNewVM::tr("&Name"));
-    m_pTypeCnt->setTitle(UIWizardNewVM::tr("OS &Type"));
+    m_pTypeCnt->setTitle(UIWizardNewVM::tr("Operating system"));
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic3.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic3.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic3.cpp	(revision 41372)
@@ -61,5 +61,4 @@
     {
         m_pLabel1 = new QIRichTextLabel(this);
-        m_pLabel2 = new QIRichTextLabel(this);
         m_pMemoryCnt = new QGroupBox(this);
         {
@@ -102,5 +101,4 @@
         }
         pMainLayout->addWidget(m_pLabel1);
-        pMainLayout->addWidget(m_pLabel2);
         pMainLayout->addWidget(m_pMemoryCnt);
         pMainLayout->addStretch();
@@ -136,12 +134,14 @@
 {
     /* Translate page: */
-    setTitle(UIWizardNewVM::tr("Memory"));
+    setTitle(UIWizardNewVM::tr("Memory size"));
 
     /* Translate widgets: */
-    m_pLabel1->setText(UIWizardNewVM::tr("<p>Select the amount of base memory (RAM) in megabytes to be allocated to the virtual machine.</p>"));
     QString strRecommendedRAM = field("type").value<CGuestOSType>().isNull() ?
                                 QString() : QString::number(field("type").value<CGuestOSType>().GetRecommendedRAM());
-    m_pLabel2->setText(UIWizardNewVM::tr("The recommended base memory size is <b>%1</b> MB.").arg(strRecommendedRAM));
-    m_pMemoryCnt->setTitle(UIWizardNewVM::tr("Base &Memory Size"));
+    m_pLabel1->setText(UIWizardNewVM::tr("<p>Select the amount of memory (RAM) in megabytes "
+                                         "to be allocated to the virtual machine.</p>"
+                                         "<p>The recommended memory size is <b>%1</b> MB.</p>")
+                                         .arg(strRecommendedRAM));
+    m_pMemoryCnt->setTitle(UIWizardNewVM::tr("&Memory size"));
     m_pRamUnits->setText(VBoxGlobal::tr("MB", "size suffix MBytes=1024 KBytes"));
     m_pRamMin->setText(QString("%1 %2").arg(m_pRamSlider->minRAM()).arg(VBoxGlobal::tr("MB", "size suffix MBytes=1024 KBytes")));
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic3.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic3.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic3.h	(revision 41372)
@@ -80,5 +80,4 @@
     /* Widgets: */
     QIRichTextLabel *m_pLabel1;
-    QIRichTextLabel *m_pLabel2;
 };
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic4.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic4.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic4.h	(revision 41372)
@@ -122,5 +122,4 @@
     /* Widgets: */
     QIRichTextLabel *m_pLabel1;
-    QIRichTextLabel *m_pLabel2;
 };
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageExpert.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageExpert.h	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageExpert.h	(revision 41372)
@@ -21,17 +21,13 @@
 
 /* Local includes: */
-#include "UIWizardNewVMPageBasic1.h"
 #include "UIWizardNewVMPageBasic2.h"
 #include "UIWizardNewVMPageBasic3.h"
 #include "UIWizardNewVMPageBasic4.h"
-#include "UIWizardNewVMPageBasic5.h"
 
 /* Expert page of the New Virtual Machine wizard: */
 class UIWizardNewVMPageExpert : public UIWizardPage,
-                                public UIWizardNewVMPage1,
                                 public UIWizardNewVMPage2,
                                 public UIWizardNewVMPage3,
-                                public UIWizardNewVMPage4,
-                                public UIWizardNewVMPage5
+                                public UIWizardNewVMPage4
 {
     Q_OBJECT;

Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic4.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic4.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/clonevd/UIWizardCloneVDPageBasic4.cpp	(revision 41372)
@@ -79,5 +79,5 @@
     QString strChosenFilePath = QIFileDialog::getSaveFileName(folder.absoluteFilePath(strFileName),
                                                               strBackendsList, thisImp(),
-                                                              VBoxGlobal::tr("Choose a virtual hard disk file"));
+                                                              UIWizardCloneVD::tr("Please choose a location for new virtual hard drive file"));
 
     /* If there was something really chosen: */
@@ -197,11 +197,11 @@
 {
     /* Translate page: */
-    setTitle(UIWizardCloneVD::tr("Virtual disk file location"));
+    setTitle(UIWizardCloneVD::tr("Copy location"));
 
     /* Translate widgets: */
-    m_pLabel->setText(UIWizardCloneVD::tr("Please type the name of the new virtual disk file into the box below or "
+    m_pLabel->setText(UIWizardCloneVD::tr("Please type the name of the new virtual hard drive file into the box below or "
                                           "click on the folder icon to select a different folder to create the file in."));
-    m_pDestinationCnt->setTitle(UIWizardCloneVD::tr("&Location"));
-    m_pDestinationDiskOpenButton->setToolTip(UIWizardCloneVD::tr("Choose a virtual hard disk file..."));
+    m_pDestinationCnt->setTitle(UIWizardCloneVD::tr("Copy &location"));
+    m_pDestinationDiskOpenButton->setToolTip(UIWizardCloneVD::tr("Choose a location for new virtual hard drive file..."));
 }
 
@@ -218,5 +218,5 @@
     m_strDefaultExtension = defaultExtension(field("mediumFormat").value<CMediumFormat>());
     /* Compose default-name for virtual-disk copy: */
-    QString strMediumName = UIWizardCloneVD::tr("%1_copy", "copied virtual disk name").arg(sourceFileInfo.baseName());
+    QString strMediumName = UIWizardCloneVD::tr("%1_copy", "copied virtual hard drive name").arg(sourceFileInfo.baseName());
     /* Set default-name as text for location editor: */
     m_pDestinationDiskEditor->setText(strMediumName);
@@ -231,12 +231,27 @@
 bool UIWizardCloneVDPageBasic4::validatePage()
 {
-    /* Make sure such virtual-disk doesn't exists already: */
+    /* Initial result: */
+    bool fResult = true;
+
+    /* Make sure such file doesn't exists already: */
     QString strMediumPath(mediumPath());
-    if (QFileInfo(strMediumPath).exists())
-    {
+    fResult = !QFileInfo(strMediumPath).exists();
+    if (!fResult)
         msgCenter().sayCannotOverwriteHardDiskStorage(this, strMediumPath);
-        return false;
-    }
-    return true;
-}
-
+
+    if (fResult)
+    {
+        /* Lock finish button: */
+        startProcessing();
+
+        /* Try to copy virtual hard drive file: */
+        fResult = qobject_cast<UIWizardCloneVD*>(wizard())->copyVirtualDisk();
+
+        /* Unlock finish button: */
+        endProcessing();
+    }
+
+    /* Return result: */
+    return fResult;
+}
+
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic3.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic3.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvd/UIWizardNewVDPageBasic3.cpp	(revision 41372)
@@ -89,5 +89,5 @@
     QString strChosenFilePath = QIFileDialog::getSaveFileName(folder.absoluteFilePath(strFileName),
                                                               strBackendsList, thisImp(),
-                                                              VBoxGlobal::tr("Choose a virtual hard disk file"));
+                                                              VBoxGlobal::tr("Please choose a location for new virtual hard drive file"));
 
     /* If there was something really chosen: */
@@ -367,12 +367,13 @@
 {
     /* Translate page: */
-    setTitle(UIWizardNewVD::tr("Virtual disk file location and size"));
+    setTitle(UIWizardNewVD::tr("Location and size"));
 
     /* Translate widgets: */
-    m_pLocationLabel->setText(UIWizardNewVD::tr("Please type the name of the new virtual disk file into the box below or "
+    m_pLocationLabel->setText(UIWizardNewVD::tr("Please type the name of the new virtual hard drive file into the box below or "
                                                 "click on the folder icon to select a different folder to create the file in."));
     m_pLocationCnt->setTitle(UIWizardNewVD::tr("&Location"));
-    m_pSizeLabel->setText(UIWizardNewVD::tr("Select the size of the virtual disk in megabytes. This size will be reported "
-                                            "to the Guest OS as the maximum size of this virtual disk."));
+    m_pLocationOpenButton->setToolTip(UIWizardNewVD::tr("Choose a location for new virtual hard drive file..."));
+    m_pSizeLabel->setText(UIWizardNewVD::tr("Select the size of the virtual hard drive in megabytes. This size will be reported "
+                                            "to the Guest OS as the maximum size of this hard drive."));
     m_pSizeCnt->setTitle(UIWizardNewVD::tr("&Size"));
 }
@@ -398,12 +399,27 @@
 bool UIWizardNewVDPageBasic3::validatePage()
 {
-    /* Make sure such virtual-disk doesn't exists already: */
+    /* Initial result: */
+    bool fResult = true;
+
+    /* Make sure such file doesn't exists already: */
     QString strMediumPath(mediumPath());
-    if (QFileInfo(strMediumPath).exists())
-    {
+    fResult = !QFileInfo(strMediumPath).exists();
+    if (!fResult)
         msgCenter().sayCannotOverwriteHardDiskStorage(this, strMediumPath);
-        return false;
-    }
-    return true;
-}
-
+
+    if (fResult)
+    {
+        /* Lock finish button: */
+        startProcessing();
+
+        /* Try to create virtual hard drive file: */
+        fResult = qobject_cast<UIWizardNewVD*>(wizard())->createVirtualDisk();
+
+        /* Unlock finish button: */
+        endProcessing();
+    }
+
+    /* Return result: */
+    return fResult;
+}
+
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic4.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic4.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageBasic4.cpp	(revision 41372)
@@ -80,5 +80,5 @@
 bool UIWizardNewVMPage4::getWithNewVirtualDiskWizard()
 {
     /* Create New Virtual Disk wizard: */
     UIWizardNewVD dlg(thisImp(),
                       fieldImp("machineBaseName").toString(),
@@ -132,5 +132,4 @@
     {
         m_pLabel1 = new QIRichTextLabel(this);
-        m_pLabel2 = new QIRichTextLabel(this);
         m_pDiskCnt = new QGroupBox(this);
         {
@@ -165,5 +164,4 @@
         }
         pMainLayout->addWidget(m_pLabel1);
-        pMainLayout->addWidget(m_pLabel2);
         pMainLayout->addWidget(m_pDiskCnt);
         pMainLayout->addStretch();
@@ -205,19 +203,20 @@
 {
     /* Translate page: */
-    setTitle(UIWizardNewVM::tr("Virtual Hard Disk"));
+    setTitle(UIWizardNewVM::tr("Hard drive"));
 
     /* Translate widgets: */
-    m_pLabel1->setText(UIWizardNewVM::tr("<p>If you wish you can now add a start-up disk to the new machine. "
-                                         "You can either create a new virtual disk or select one from the list "
-                                         "or from another location using the folder icon.</p>"
-                                         "<p>If you need a more complex virtual disk setup you can skip this step "
-                                         "and make the changes to the machine settings once the machine is created.</p>"));
     QString strRecommendedHDD = field("type").value<CGuestOSType>().isNull() ? QString() :
                                 VBoxGlobal::formatSize(field("type").value<CGuestOSType>().GetRecommendedHDD());
-    m_pLabel2->setText(UIWizardNewVM::tr("The recommended size of the start-up disk is <b>%1</b>.").arg(strRecommendedHDD));
-    m_pDiskCnt->setTitle(UIWizardNewVM::tr("Start-up &Disk"));
-    m_pDiskCreate->setText(UIWizardNewVM::tr("&Create new hard disk"));
-    m_pDiskPresent->setText(UIWizardNewVM::tr("&Use existing hard disk"));
-    m_pVMMButton->setToolTip(UIWizardNewVM::tr("Choose a virtual hard disk file..."));
+    m_pLabel1->setText(UIWizardNewVM::tr("<p>If you wish you can add a virtual hard drive to the new machine. "
+                                         "You can either create a new hard drive file or select one from the list "
+                                         "or from another location using the folder icon.</p>"
+                                         "<p>If you need a more complex storage set-up you can skip this step "
+                                         "and make the changes to the machine settings once the machine is created.</p>"
+                                         "<p>The recommended size of the hard drive is <b>%1</b>.</p>")
+                                         .arg(strRecommendedHDD));
+    m_pDiskCnt->setTitle(UIWizardNewVM::tr("Hard &drive"));
+    m_pDiskCreate->setText(UIWizardNewVM::tr("&Create new virtual hard drive"));
+    m_pDiskPresent->setText(UIWizardNewVM::tr("&Use existing virtual hard drive file"));
+    m_pVMMButton->setToolTip(UIWizardNewVM::tr("Choose a virtual hard drive file..."));
 }
 
@@ -267,6 +266,18 @@
     else if (m_pDiskCreate->isChecked())
     {
         /* Show the New Virtual Disk wizard: */
         fResult = getWithNewVirtualDiskWizard();
+    }
+
+    if (fResult)
+    {
+        /* Lock finish button: */
+        startProcessing();
+
+        /* Try to create VM: */
+        fResult = qobject_cast<UIWizardNewVM*>(wizard())->createVM();
+
+        /* Unlock finish button: */
+        endProcessing();
     }
 
@@ -80,5 +80,5 @@
 bool UIWizardNewVMPage4::getWithNewVirtualDiskWizard()
 {
-    /* Create New Virtual Disk wizard: */
+    /* Create New Virtual Hard Drive wizard: */
     UIWizardNewVD dlg(thisImp(),
                       fieldImp("machineBaseName").toString(),
@@ -267,6 +266,18 @@
     else if (m_pDiskCreate->isChecked())
     {
-        /* Show the New Virtual Disk wizard: */
+        /* Show the New Virtual Hard Drive wizard: */
         fResult = getWithNewVirtualDiskWizard();
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageExpert.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageExpert.cpp	(revision 41371)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMPageExpert.cpp	(revision 41372)
@@ -238,13 +238,13 @@
     /* Translate widgets: */
     m_pNameCnt->setTitle(UIWizardNewVM::tr("&Name"));
-    m_pTypeCnt->setTitle(UIWizardNewVM::tr("OS &Type"));
-    m_pMemoryCnt->setTitle(UIWizardNewVM::tr("Base &Memory Size"));
+    m_pTypeCnt->setTitle(UIWizardNewVM::tr("Operating system"));
+    m_pMemoryCnt->setTitle(UIWizardNewVM::tr("&Memory size"));
     m_pRamUnits->setText(VBoxGlobal::tr("MB", "size suffix MBytes=1024 KBytes"));
     m_pRamMin->setText(QString("%1 %2").arg(m_pRamSlider->minRAM()).arg(VBoxGlobal::tr("MB", "size suffix MBytes=1024 KBytes")));
     m_pRamMax->setText(QString("%1 %2").arg(m_pRamSlider->maxRAM()).arg(VBoxGlobal::tr("MB", "size suffix MBytes=1024 KBytes")));
-    m_pDiskCnt->setTitle(UIWizardNewVM::tr("Start-up &Disk"));
-    m_pDiskCreate->setText(UIWizardNewVM::tr("&Create new hard disk"));
-    m_pDiskPresent->setText(UIWizardNewVM::tr("&Use existing hard disk"));
-    m_pVMMButton->setToolTip(UIWizardNewVM::tr("Choose a virtual hard disk file..."));
+    m_pDiskCnt->setTitle(UIWizardNewVM::tr("Hard &drive"));
+    m_pDiskCreate->setText(UIWizardNewVM::tr("&Create new virtual hard drive"));
+    m_pDiskPresent->setText(UIWizardNewVM::tr("&Use existing virtual hard drive file"));
+    m_pVMMButton->setToolTip(UIWizardNewVM::tr("Choose a virtual hard drive file..."));
 }
 
@@ -296,5 +296,5 @@
             if (m_pDiskCnt->isChecked() && m_pDiskCreate->isChecked())
             {
                 /* Show the New Virtual Disk wizard if necessary: */
                 fResult = getWithNewVirtualDiskWizard();
             }
@@ -296,5 +296,5 @@
             if (m_pDiskCnt->isChecked() && m_pDiskCreate->isChecked())
             {
-                /* Show the New Virtual Disk wizard if necessary: */
+                /* Show the New Virtual Hard Drive wizard if necessary: */
                 fResult = getWithNewVirtualDiskWizard();
             }